@@ -2,11 +2,9 @@
 ## Re-parameterized Inverse Gaussian distribution ##
 ####################################################
 
-library(statmod)
-
 dig <- function(x,mu,var,log=FALSE){
   
-  dinvgauss(x, mean=mu, dispersion=var/mu^3, log=log)
+  statmod::dinvgauss(x, mean=mu, dispersion=var/mu^3, log=log)
   
 }
 
